DROP TABLE icons_movies;
DROP TABLE scenes;
DROP TABLE filters;

ALTER TABLE movies RENAME TO _movies;
ALTER TABLE user RENAME TO _user;
ALTER TABLE files RENAME TO _files;

CREATE TABLE scenes (
	scenes INTEGER PRIMARY KEY ASC,
	movies INTEGER DEFAULT '',
	time INTEGER DEFAULT '',
	name TEXT DEFAULT '',
	unique(movies,time)
);

CREATE TABLE filters (
	filters INTEGER DEFAULT '',
	name TEXT DEFAULT '',
	unique(filters)
);

CREATE TABLE sections_ids_count (
	section TEXT NOT NULL,
	id INTEGER NOT NULL,
	count INTEGER DEFAULT 0,
	UNIQUE(section,id)
);

CREATE TABLE sections_count (
	section TEXT NOT NULL,
	count INTEGER DEFAULT 0,
	UNIQUE(section)
);

CREATE TABLE options (
	var TEXT,
	value TEXT,
	UNIQUE(var,value)
);

CREATE TABLE files (
	files INTEGER PRIMARY KEY ASC,
	movies INTEGER DEFAULT '',
	modified INTEGER DEFAULT '',
	size INTEGER DEFAULT '',
	path TEXT DEFAULT '',
	title TEXT DEFAULT '',
	unique(path)
);

CREATE TABLE movies (
	movies INTEGER DEFAULT '',
	year INTEGER DEFAULT '',
	imdb_rating INTEGER DEFAULT '',
	votes INTEGER DEFAULT '',
	runtime INTEGER DEFAULT '',
	icon_width INTEGER DEFAULT '',
	icon_height INTEGER DEFAULT '',
	icon_alpha INTEGER DEFAULT '',
	icon_modified INTEGER DEFAULT '',
	rating INTEGER DEFAULT '',
	popularity INTEGER DEFAULT '',
	rated INTEGER DEFAULT '',
	last_played INTEGER DEFAULT '',
	play_count INTEGER DEFAULT '',
	on_disk INTEGER DEFAULT '',
	name TEXT DEFAULT '',
	original_title TEXT DEFAULT '',
	type TEXT DEFAULT '',
	plot TEXT DEFAULT '',
	color TEXT DEFAULT '',
	comment TEXT DEFAULT '',
	buy_movie TEXT DEFAULT '',
	watch_now TEXT DEFAULT '',
	added TEXT DEFAULT (datetime('now','localtime')),
	updated TEXT DEFAULT (datetime('now','localtime')),
	unique(movies)
);

CREATE VIEW movies_filters AS
	SELECT '1' AS filters,movies FROM movies WHERE  movies.rated != ''
	UNION ALL
	SELECT '2' AS filters,movies FROM movies WHERE NOT movies.rated != '' AND  movies.on_disk != ''
	UNION ALL
	SELECT '3' AS filters,movies FROM movies WHERE  movies.on_disk != ''
	UNION ALL
	SELECT '4' AS filters,movies FROM movies WHERE NOT movies.rating != '' AND NOT movies.on_disk != ''
;

INSERT INTO movies
	SELECT movies,year,imdb_rating,votes,runtime,icon_width,icon_height,icon_alpha,icon_modified,rating,popularity,rated,last_played,play_count,'',name,'',type,plot,color,comment,'','',added,''
		FROM _movies natural left join _user;
INSERT INTO files SELECT rowid,movies,modified,size,files,'' from _files;
INSERT INTO options (var,value) VALUES('dbVersion','90');

UPDATE movies SET on_disk = '1' WHERE movies IN (SELECT movies FROM files);
UPDATE movies SET type = 'Video' WHERE type = 'V';
UPDATE movies SET type = 'TV' WHERE type = '(TV';
UPDATE movies SET type = 'TV series' WHERE type = '(TV Series';

INSERT INTO filters VALUES('1','viewed');
INSERT INTO filters VALUES('2','to_see');
INSERT INTO filters VALUES('3','on_disk');
INSERT INTO filters VALUES('4','whishlist');

INSERT INTO sections_count SELECT 'movies',count(*) FROM movies;
INSERT INTO sections_ids_count SELECT 'year',year,count(year) FROM movies GROUP BY year;
INSERT INTO sections_ids_count SELECT 'type',type,count(type) FROM movies GROUP BY type;
INSERT INTO sections_ids_count SELECT 'creators',people,count(people) FROM creators GROUP BY people;
INSERT INTO sections_ids_count SELECT 'directors',people,count(people) FROM directors GROUP BY people;
INSERT INTO sections_ids_count SELECT 'writers',people,count(people) FROM writers GROUP BY people;
INSERT INTO sections_ids_count SELECT 'actors',people,count(people) FROM actors GROUP BY people;
INSERT INTO sections_ids_count SELECT 'characters',characters,count(characters) FROM actors GROUP BY characters;
INSERT INTO sections_ids_count SELECT 'companies',companies,count(companies) FROM movies_companies GROUP BY companies;
INSERT INTO sections_ids_count SELECT 'genres',genres,count(genres) FROM genres GROUP BY genres;
INSERT INTO sections_ids_count SELECT 'countries',countries,count(countries) FROM countries GROUP BY countries;
INSERT INTO sections_ids_count SELECT 'languages',languages,count(languages) FROM languages GROUP BY languages;
INSERT INTO sections_ids_count SELECT 'sound',sound,count(sound) FROM sound GROUP BY sound;
INSERT INTO sections_ids_count SELECT 'tags',tags,count(tags) FROM tags GROUP BY tags;
INSERT INTO sections_count SELECT 'files',count(*) FROM files;
INSERT INTO sections_ids_count SELECT 'keywords',keywords,count(keywords) FROM keywords GROUP BY keywords;
INSERT INTO sections_count SELECT 'filters',count(*) FROM filters;
INSERT INTO sections_ids_count SELECT 'scenes',scenes,count(scenes) FROM scenes GROUP BY scenes;
INSERT INTO sections_count SELECT 'borrowers',count(*) FROM borrowers;

INSERT INTO sections_count SELECT section,count(section) FROM sections_ids_count GROUP BY section;;
DELETE FROM sections_count WHERE count = 0;
